netapp_ontap.models.lun_copy_destinations API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_copy_destinations`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunCopyDestinationsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunCopyDestinations object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the lun_copy_destinations.

  `max_throughput: Size GET`

    The maximum data throughput, in bytes per second, that should be utilized in support of the LUN copy. See property `copy.source.max_throughput` for further details.

  `name: str GET`

    The fully qualified path of the LUN copy destination composed of a "/vol" prefix, the volume name, the optional qtree name, and base name of the LUN.

    Example: /vol/vol1/lun1

  `peer: SvmPeer GET POST PATCH`

    The peer field of the lun_copy_destinations.

  `progress: LunCopyDestinationsProgress GET POST PATCH`

    Properties related to the progress of an active or recently completed LUN copy.

  `uuid: str GET`

    The unique identifier of the LUN copy destination.

    Example: 1bc327d5-4654-5284-a116-f182282240b4